==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/seekthru/leechcraft_seekthru_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>LeechCraft::Plugins::SeekThru::Core</name>
    <message>
        <location filename="core.cpp" line="46"/>
        <source>Short name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="97"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="99"/>
        <source>Limited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="101"/>
        <source>Private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="103"/>
        <source>Closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="183"/>
        <source>%1 wasn&apos;t delegated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="270"/>
        <source>Could not open file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="280"/>
        <source>Could not remove temporary file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="288"/>
        <source>A job was delegated, but it failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="301"/>
        <source>XML parse error %1 at %2:%3.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="311"/>
        <source>Not and OpenSearch description.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="324"/>
        <source>Malformed OpenSearch description.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="357"/>
        <source>Enter categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="358"/>
        <source>Please enter categories for this searcher:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchHandler</name>
    <message>
        <location filename="searchhandler.cpp" line="48"/>
        <source>Subscribe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="73"/>
        <source>%1 total results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="76"/>
        <source>Unknown number of results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="83"/>
        <source> (RSS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="86"/>
        <source> (Atom)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="89"/>
        <source> (HTML)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="216"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="240"/>
        <source>Could not open file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="251"/>
        <source>Could not remove temporary file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="295"/>
        <source>Search request for URL&lt;br /&gt;%1&lt;br /&gt;was delegated, but it failed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchersList</name>
    <message>
        <location filename="searcherslist.cpp" line="49"/>
        <source>No description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="55"/>
        <source>No long name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="64"/>
        <source>No contacts information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="70"/>
        <source>No developer information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="76"/>
        <source>No attribution information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="82"/>
        <source>No right information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="87"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="87"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="96"/>
        <source>Adding a new searcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="97"/>
        <source>Enter the URL of the OpenSearch description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SeekThru</name>
    <message>
        <location filename="seekthru.cpp" line="76"/>
        <source>Search via OpenSearch-aware search providers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="seekthru.cpp" line="132"/>
        <location filename="seekthru.cpp" line="139"/>
        <source>LeechCraft</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchersList</name>
    <message>
        <location filename="searcherslist.ui" line="14"/>
        <source>Searchers list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="24"/>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="30"/>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="40"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="60"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="69"/>
        <source>Long name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="83"/>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="93"/>
        <source>Tags:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="100"/>
        <source>Contact:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="114"/>
        <source>Attribution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="128"/>
        <source>Right:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="142"/>
        <source>Developer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="156"/>
        <source>Adult:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="170"/>
        <source>Languages:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/seekthru/leechcraft_seekthru_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>LeechCraft::Plugins::SeekThru::Core</name>
    <message>
        <location filename="core.cpp" line="71"/>
        <source>Short name</source>
        <translation>Mallonga nomo</translation>
    </message>
    <message>
        <location filename="core.cpp" line="113"/>
        <source>Open</source>
        <translation>Malfermi</translation>
    </message>
    <message>
        <location filename="core.cpp" line="115"/>
        <source>Limited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="117"/>
        <source>Private</source>
        <translation>Privata</translation>
    </message>
    <message>
        <location filename="core.cpp" line="119"/>
        <source>Closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="199"/>
        <source>%1 wasn&apos;t delegated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="307"/>
        <source>Could not open file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="317"/>
        <source>Could not remove temporary file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="325"/>
        <source>A job was delegated, but it failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="377"/>
        <source>XML parse error %1 at %2:%3.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchHandler</name>
    <message>
        <location filename="searchhandler.cpp" line="49"/>
        <source>Subscribe</source>
        <translation>Subskribi</translation>
    </message>
    <message numerus="yes">
        <location filename="searchhandler.cpp" line="74"/>
        <source>%n total result(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="76"/>
        <source>Unknown number of results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="218"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="242"/>
        <source>Could not open file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="253"/>
        <source>Could not remove temporary file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="297"/>
        <source>Search request for URL&lt;br /&gt;%1&lt;br /&gt;was delegated, but it failed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchersList</name>
    <message>
        <location filename="searcherslist.cpp" line="52"/>
        <source>No description</source>
        <translation>Nenio priskribo</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="58"/>
        <source>No long name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="68"/>
        <source>No contacts information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="74"/>
        <source>No developer information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="80"/>
        <source>No attribution information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="86"/>
        <source>No right information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="91"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="91"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="100"/>
        <source>Adding a new searcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="101"/>
        <source>Enter the URL of the OpenSearch description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SeekThru</name>
    <message>
        <location filename="seekthru.cpp" line="90"/>
        <source>Search via OpenSearch-aware search providers.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::StartupFirstPage</name>
    <message>
        <location filename="startupfirstpage.cpp" line="72"/>
        <source>Select default search engines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchersList</name>
    <message>
        <location filename="searcherslist.ui" line="14"/>
        <source>Searchers list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="24"/>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="30"/>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="40"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="60"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="69"/>
        <source>Long name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="83"/>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="93"/>
        <source>Tags:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="100"/>
        <source>Contact:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="114"/>
        <source>Attribution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="128"/>
        <source>Right:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="142"/>
        <source>Developer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="156"/>
        <source>Adult:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="170"/>
        <source>Languages:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StartupFirstPageWidget</name>
    <message>
        <location filename="startupfirstpage.ui" line="22"/>
        <source>Localized set:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="30"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="35"/>
        <source>Russian (ru)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="59"/>
        <source>Engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="64"/>
        <source>Tags</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagsAsker</name>
    <message>
        <location filename="tagsasker.ui" line="22"/>
        <source>Tags for this searcher:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
